@@ -5,16 +5,12 @@
 
 import uuid
 
-from .models import IdentityKey, SignedPreKey, PreKey, EncryptingSenderKey, DecryptingSenderKey, Party
+from .models import IdentityKey, SignedPreKey, PreKey, EncryptingSenderKey, DecryptingSenderKey, PendingKey, Party
 from django.db.models import Q
 from firebase_admin import db
 from django.conf import settings
 from django.utils.dateformat import format
 
-DEFAULT_APP = settings.DEFAULT_APP
-FIREBASE_REF = settings.FIREBASE_REF
-FIREBASE_REF_DEV = settings.FIREBASE_REF_DEV
-
 
 #
 # @author Omar Basem
@@ -209,12 +205,10 @@ class StickProtocol():
                 key = {'id': senderKey.keyId, 'key': senderKey.key, 'step': senderKey.step, 'identityKeyId': senderKey.identityKey.keyId}
         # SenderKey does not exist, send a `PendingKey` request to the target user to upload their key,
         # through a realtime database.
-        else: # todo: refactor firebase out?
-            phone = self.User.objects.get(id=memberId).phone
-            isDev = data['isDev']
-            firebase_ref = FIREBASE_REF_DEV if isDev else FIREBASE_REF
-            ref = db.reference('users/' + phone + '/pendingKeys/', DEFAULT_APP, firebase_ref)
-            ref.update({stickId + '--' + str(user.id): user.phone})
+        else:
+            if not PendingKey.objects.filter(user=user, stickId=stickId).exists():
+                owner = self.User.objects.get(id=memberId)
+                PendingKey.objects.create(user=user, owner=owner, stickId=stickId)
         return {'authorized': authorized, 'senderKey': key}
 
     def get_standard_sender_keys(self, data, user, group):
